@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 """
-=====================================
-scikit-nano: Toolkit for nano-science
-=====================================
+============================================================================
+scikit-nano: Python toolkit for generating and analyzing nanostructure data
+============================================================================
 
 Contents
 ========
@@ -14,6 +14,7 @@ Subpackages
 
  chemistry      --- abstract data structures for chemistry
  nanogen        --- modules for structure analysis and structure generation
+ nanogen_gui    --- NanoGen GUI front-end
  scripts        --- command-line scripts
  structure_io   --- classes for structure data I/O
  tools          --- tools for analysis, helper funcs, LUTs, etc.
@@ -28,14 +29,11 @@ Utilitiy tools
 """
 from __future__ import print_function, absolute_import
 
-__all__ = ['chemistry', 'nanogen', 'scripts', 'structure_io', 'tools']
+__all__ = ['chemistry',
+           'nanogen',
+           'nanogen_gui',
+           'scripts',
+           'structure_io',
+           'tools']
 
 from sknano.version import version as __version__
-
-
-def get_path():
-    try:
-        from pkthemes import get_path
-        return get_path()
-    except ImportError:
-        return None
