@@ -11,8 +11,6 @@ from __future__ import division, print_function, absolute_import
 __docformat__ = 'restructuredtext'
 
 #import itertools
-import warnings
-warnings.filterwarnings('ignore')  # to suppress the Pint UnicodeWarning
 
 #from fractions import gcd
 #from collections import OrderedDict
@@ -36,6 +34,11 @@ __all__ = ['Fullerene']
 class Fullerene(object):
     u"""Class for creating interactive Fullerene objects.
 
+    .. note::
+
+       This class is under development and not functional! Attempting
+       to use it raises a `RuntimeError`.
+
     The `fullerene isomer data
     <http://www.nanotube.msu.edu/fullerene/fullerene-isomers.html>`_
     were downloaded from the
