@@ -7,21 +7,15 @@ Nanotube bundle generators (:mod:`sknano.nanogen._nanotube_bundle_generators`)
 .. currentmodule:: sknano.nanogen._nanotube_bundle_generators
 
 """
-from __future__ import division, print_function, absolute_import
-__docformat__ = 'restructuredtext'
+from __future__ import absolute_import, division, print_function
+__docformat__ = 'restructuredtext en'
 
 import copy
 #import itertools
 
-#from pint import UnitRegistry
-#ureg = UnitRegistry()
-#Qty = ureg.Quantity
-
 import numpy as np
 
 from ..chemistry import Atom, Atoms
-from ..structure_io import default_structure_format, \
-    supported_structure_formats
 from ..tools import plural_word_check
 from ..tools.refdata import CCbond
 
@@ -45,7 +39,7 @@ class NanotubeBundleGenerator(NanotubeGenerator, NanotubeBundle):
         Number of repeat unit cells in the :math:`x, y, z` dimensions.
     element1, element2 : {str, int}, optional
         Element symbol or atomic number of basis
-        :py:class:`~sknano.chemistry.Atoms` 1 and 2
+        :class:`~sknano.chemistry.Atoms` 1 and 2
     bond : float, optional
         :math:`\\mathrm{a}_{\\mathrm{CC}} =` distance between
         nearest neighbor atoms. Must be in units of **Angstroms**.
@@ -84,8 +78,8 @@ class NanotubeBundleGenerator(NanotubeGenerator, NanotubeBundle):
 
     autogen : bool, optional
         if `True`, automatically call
-        :py:meth:`~NanotubeGenerator.generate_unit_cell`,
-        followed by :py:meth:`~NanotubeGenerator.generate_structure_data`.
+        :meth:`~NanotubeGenerator.generate_unit_cell`,
+        followed by :meth:`~NanotubeGenerator.generate_structure_data`.
     verbose : bool, optional
         if `True`, show verbose output
 
@@ -133,7 +127,7 @@ class NanotubeBundleGenerator(NanotubeGenerator, NanotubeBundle):
 
     .. image:: /images/0605_hcp_7tube_hexagon-01.png
 
-    Remember, all of the :py:meth:`~NanotubeBundleGenerator.save_data`
+    Remember, all of the :meth:`~NanotubeBundleGenerator.save_data`
     methods allow you to rotate the structure data before saving:
 
     >>> SWCNTbundle.save_data(fname='0605_hcp_7tube_hexagon_rot-30deg.xyz',
@@ -266,42 +260,16 @@ class NanotubeBundleGenerator(NanotubeGenerator, NanotubeBundle):
                                            Ntubes=self._Ntubes)
         #self.update_structure_atoms_attributes()
 
-    def save_data(self, fname=None, structure_format=None,
+    def save_data(self, fname=None, outpath=None, structure_format=None,
                   rotation_angle=None, rot_axis=None, deg2rad=True,
                   center_CM=True):
         """Save structure data.
 
-        Parameters
-        ----------
-        fname : {None, str}, optional
-            file name string
-        structure_format : {None, str}, optional
-            chemical file format of saved structure data. Must be one of:
-
-                - xyz
-                - data
-
-            If `None`, then guess based on `fname` file extension or
-            default to `xyz` format.
-        rotation_angle : {None, float}, optional
-            Angle of rotation
-        rot_axis : {'x', 'y', 'z'}, optional
-            Rotation axis
-        deg2rad : bool, optional
-            Convert `rotation_angle` from degrees to radians.
-        center_CM : bool, optional
-            Center center-of-mass on origin.
+        See :meth:`~sknano.nanogen.StructureGenerator.save_data` method
+        for documentation.
 
         """
-        if (fname is None and structure_format not in
-                supported_structure_formats) or \
-                (fname is not None and not
-                    fname.endswith(supported_structure_formats) and
-                    structure_format not in supported_structure_formats):
-            structure_format = default_structure_format
-
         if fname is None:
-
             chirality = '{}{}'.format('{}'.format(self._n).zfill(2),
                                       '{}'.format(self._m).zfill(2))
             packing = '{}cp'.format(self._bundle_packing[0])
@@ -328,22 +296,9 @@ class NanotubeBundleGenerator(NanotubeGenerator, NanotubeBundle):
                     (chirality, packing, Ntube, self._bundle_geometry)
 
             fname = '_'.join(fname_wordlist)
-            fname += '.' + structure_format
-
-        else:
-            if fname.endswith(supported_structure_formats) and \
-                    structure_format is None:
-                for ext in supported_structure_formats:
-                    if fname.endswith(ext):
-                        structure_format = ext
-                        break
-            else:
-                if structure_format is None or \
-                        structure_format not in supported_structure_formats:
-                    structure_format = default_structure_format
 
         super(NanotubeBundleGenerator, self).save_data(
-            fname=fname, structure_format=structure_format,
+            fname=fname, outpath=outpath, structure_format=structure_format,
             rotation_angle=rotation_angle, rot_axis=rot_axis,
             deg2rad=deg2rad, center_CM=center_CM)
 
@@ -362,7 +317,7 @@ class MWNTBundleGenerator(MWNTGenerator, NanotubeBundle):
         Number of repeat unit cells in the :math:`x, y, z` dimensions.
     element1, element2 : {str, int}, optional
         Element symbol or atomic number of basis
-        :py:class:`~sknano.chemistry.Atoms` 1 and 2
+        :class:`~sknano.chemistry.Atoms` 1 and 2
     bond : float, optional
         :math:`\\mathrm{a}_{\\mathrm{CC}} =` distance between
         nearest neighbor atoms. Must be in units of **Angstroms**.
@@ -411,8 +366,8 @@ class MWNTBundleGenerator(MWNTGenerator, NanotubeBundle):
                        'rhombus', 'rhomboid'}, optional
     autogen : bool, optional
         if `True`, automatically call
-        :py:meth:`~MWNTGenerator.generate_unit_cell`,
-        followed by :py:meth:`~MWNTGenerator.generate_structure_data`.
+        :meth:`~MWNTGenerator.generate_unit_cell`,
+        followed by :meth:`~MWNTGenerator.generate_structure_data`.
     verbose : bool, optional
         if `True`, show verbose output
 
@@ -583,49 +538,21 @@ class MWNTBundleGenerator(MWNTGenerator, NanotubeBundle):
             print('Ntubes: {}'.format(self._Ntubes))
             print('Natoms_per_bundle: {}'.format(self._Natoms_per_bundle))
 
-    def save_data(self, fname=None, structure_format=None,
+    def save_data(self, fname=None, outpath=None, structure_format=None,
                   rotation_angle=None, rot_axis=None, deg2rad=True,
                   center_CM=True):
         """Save structure data.
 
-        Parameters
-        ----------
-        fname : {None, str}, optional
-            file name string
-        structure_format : {None, str}, optional
-            chemical file format of saved structure data. Must be one of:
-
-                - xyz
-                - data
-
-            If `None`, then guess based on `fname` file extension or
-            default to `xyz` format.
-        rotation_angle : {None, float}, optional
-            Angle of rotation
-        rot_axis : {'x', 'y', 'z'}, optional
-            Rotation axis
-        deg2rad : bool, optional
-            Convert `rotation_angle` from degrees to radians.
-        center_CM : bool, optional
-            Center center-of-mass on origin.
+        See :meth:`~sknano.nanogen.StructureGenerator.save_data` method
+        for documentation.
 
         """
-        if (fname is None and structure_format not in
-                supported_structure_formats) or \
-                (fname is not None and not
-                    fname.endswith(supported_structure_formats) and
-                    structure_format not in supported_structure_formats):
-            structure_format = default_structure_format
-
         if fname is None:
-
             Nshells = '{}shell_mwnt'.format(self._Nshells_per_tube)
-
             chirality = '{}{}_{}_Ch'.format('{}'.format(self._n).zfill(2),
                                             '{}'.format(self._m).zfill(2),
                                             self._starting_shell_position)
             packing = '{}cp'.format(self._bundle_packing[0])
-
             Ntubes = '{}tube'.format(self._Ntubes)
 
             fname_wordlist = None
@@ -652,21 +579,8 @@ class MWNTBundleGenerator(MWNTGenerator, NanotubeBundle):
                      self._bundle_geometry)
 
             fname = '_'.join(fname_wordlist)
-            fname += '.' + structure_format
-
-        else:
-            if fname.endswith(supported_structure_formats) and \
-                    structure_format is None:
-                for ext in supported_structure_formats:
-                    if fname.endswith(ext):
-                        structure_format = ext
-                        break
-            else:
-                if structure_format is None or \
-                        structure_format not in supported_structure_formats:
-                    structure_format = default_structure_format
 
         super(MWNTBundleGenerator, self).save_data(
-            fname=fname, structure_format=structure_format,
+            fname=fname, outpath=outpath, structure_format=structure_format,
             rotation_angle=rotation_angle, rot_axis=rot_axis,
             deg2rad=deg2rad, center_CM=center_CM)
