@@ -16,23 +16,17 @@ Nanotube structure generators (:mod:`sknano.nanogen._nanotube_generators`)
    Handle different units in output coordinates.
 
 """
-from __future__ import division, print_function, absolute_import
-__docformat__ = 'restructuredtext'
+from __future__ import absolute_import, division, print_function
+__docformat__ = 'restructuredtext en'
 
 import copy
 #import itertools
 #import sys
 
-#from pint import UnitRegistry
-#ureg = UnitRegistry()
-#Qty = ureg.Quantity
-
 import numpy as np
 
 from ..chemistry import Atom, Atoms
-from ..structure_io import DATAWriter, XYZWriter, default_structure_format, \
-    supported_structure_formats
-from ..tools import plural_word_check, rotation_matrix
+from ..tools import plural_word_check
 from ..tools.refdata import CCbond
 
 from ._nanotubes import Nanotube
@@ -54,7 +48,7 @@ class NanotubeGenerator(Nanotube, StructureGenerator):
         the *length* of the nanotube.
     element1, element2 : {str, int}, optional
         Element symbol or atomic number of basis
-        :py:class:`~sknano.chemistry.Atoms` 1 and 2
+        :class:`~sknano.chemistry.Atoms` 1 and 2
     bond : float, optional
         :math:`\\mathrm{a}_{\\mathrm{CC}} =` distance between
         nearest neighbor atoms. Must be in units of **Angstroms**.
@@ -80,8 +74,8 @@ class NanotubeGenerator(Nanotube, StructureGenerator):
 
     autogen : bool, optional
         if `True`, automatically call
-        :py:meth:`~NanotubeGenerator.generate_unit_cell`,
-        followed by :py:meth:`~NanotubeGenerator.generate_structure_data`.
+        :meth:`~NanotubeGenerator.generate_unit_cell`,
+        followed by :meth:`~NanotubeGenerator.generate_structure_data`.
     with_units : bool, optional
         Attach `units` to physical quantities
     units : None, optional
@@ -91,7 +85,7 @@ class NanotubeGenerator(Nanotube, StructureGenerator):
 
     Examples
     --------
-    First, load the :py:class:`~sknano.nanogen.NanotubeGenerator` class.
+    First, load the :class:`~sknano.nanogen.NanotubeGenerator` class.
 
     >>> from sknano.nanogen import NanotubeGenerator
 
@@ -198,40 +192,15 @@ class NanotubeGenerator(Nanotube, StructureGenerator):
                 nt_atom.r = uc_atom.r + dr
                 self._structure_atoms.append(nt_atom)
 
-    def save_data(self, fname=None, structure_format=None,
+    def save_data(self, fname=None, outpath=None, structure_format=None,
                   rotation_angle=None, rot_axis=None, deg2rad=True,
                   center_CM=True):
         """Save structure data.
 
-        Parameters
-        ----------
-        fname : {None, str}, optional
-            file name string
-        structure_format : {None, str}, optional
-            chemical file format of saved structure data. Must be one of:
-
-                - xyz
-                - data
-
-            If `None`, then guess based on `fname` file extension or
-            default to `xyz` format.
-        rotation_angle : {None, float}, optional
-            Angle of rotation
-        rot_axis : {'x', 'y', 'z'}, optional
-            Rotation axis
-        deg2rad : bool, optional
-            Convert `rotation_angle` from degrees to radians.
-        center_CM : bool, optional
-            Center center-of-mass on origin.
+        See :meth:`~sknano.nanogen.StructureGenerator.save_data` method
+        for documentation.
 
         """
-        if (fname is None and structure_format not in
-                supported_structure_formats) or \
-                (fname is not None and not
-                    fname.endswith(supported_structure_formats) and
-                    structure_format not in supported_structure_formats):
-            structure_format = default_structure_format
-
         if fname is None:
             chirality = '{}{}r'.format('{}'.format(self._n).zfill(2),
                                        '{}'.format(self._m).zfill(2))
@@ -243,20 +212,6 @@ class NanotubeGenerator(Nanotube, StructureGenerator):
                               plural_word_check('cell', self._nz)))
             fname_wordlist = (chirality, nz)
             fname = '_'.join(fname_wordlist)
-            fname += '.' + structure_format
-        else:
-            if fname.endswith(supported_structure_formats) and \
-                    structure_format is None:
-                for ext in supported_structure_formats:
-                    if fname.endswith(ext):
-                        structure_format = ext
-                        break
-            else:
-                if structure_format is None or \
-                        structure_format not in supported_structure_formats:
-                    structure_format = default_structure_format
-
-        self._fname = fname
 
         if center_CM:
             self._structure_atoms.center_CM()
@@ -271,16 +226,10 @@ class NanotubeGenerator(Nanotube, StructureGenerator):
             if center_CM:
                 self._structure_atoms.center_CM()
 
-        if rotation_angle is not None:
-            R_matrix = rotation_matrix(rotation_angle,
-                                       rot_axis=rot_axis,
-                                       deg2rad=deg2rad)
-            self._structure_atoms.rotate(R_matrix)
-
-        if structure_format == 'data':
-            DATAWriter.write(fname=self._fname, atoms=self._structure_atoms)
-        else:
-            XYZWriter.write(fname=self._fname, atoms=self._structure_atoms)
+        super(NanotubeGenerator, self).save_data(
+            fname=fname, outpath=outpath, structure_format=structure_format,
+            rotation_angle=rotation_angle, rot_axis=rot_axis,
+            deg2rad=deg2rad, center_CM=False)
 
 
 class CappedNanotubeGenerator(Nanotube, StructureGenerator):
@@ -302,7 +251,7 @@ class UnrolledNanotubeGenerator(Nanotube, StructureGenerator):
         Number of repeat unit cells in the :math:`x, y, z` dimensions
     element1, element2 : {str, int}, optional
         Element symbol or atomic number of basis
-        :py:class:`~sknano.chemistry.Atoms` 1 and 2
+        :class:`~sknano.chemistry.Atoms` 1 and 2
     bond : float, optional
         :math:`\\mathrm{a}_{\\mathrm{CC}} =` distance between
         nearest neighbor atoms. Must be in units of **Angstroms**.
@@ -315,8 +264,8 @@ class UnrolledNanotubeGenerator(Nanotube, StructureGenerator):
         non integer :math:`n_z` cells are permitted.
     autogen : bool, optional
         if `True`, automatically call
-        :py:meth:`~NanotubeGenerator.generate_unit_cell`,
-        followed by :py:meth:`~NanotubeGenerator.generate_structure_data`.
+        :meth:`~NanotubeGenerator.generate_unit_cell`,
+        followed by :meth:`~NanotubeGenerator.generate_structure_data`.
     with_units : bool, optional
         Attach `units` to physical quantities
     units : None, optional
@@ -331,14 +280,14 @@ class UnrolledNanotubeGenerator(Nanotube, StructureGenerator):
     :math:`\\mathbf{C}_{h} = n\\mathbf{a}_{1} + m\\mathbf{a}_{2} = (n, m)`.
     If you want to generate graphene with an armchair or zigzag edge using
     `length` and `width` parameters, see the
-    :py:class:`~sknano.nanogen.GrapheneGenerator` class.
+    :class:`~sknano.nanogen.GrapheneGenerator` class.
 
-    .. seealso:: :py:class:`~sknano.nanogen.GrapheneGenerator`
+    .. seealso:: :class:`~sknano.nanogen.GrapheneGenerator`
 
 
     Examples
     --------
-    First, load the :py:class:`~sknano.nanogen.UnrolledNanotubeGenerator`
+    First, load the :class:`~sknano.nanogen.UnrolledNanotubeGenerator`
     class.
 
     >>> from sknano.nanogen import UnrolledNanotubeGenerator
@@ -436,44 +385,18 @@ class UnrolledNanotubeGenerator(Nanotube, StructureGenerator):
                     nt_atom.r = uc_atom.r + dr
                     self._structure_atoms.append(nt_atom)
 
-    def save_data(self, fname=None, structure_format=None,
+    def save_data(self, fname=None, outpath=None, structure_format=None,
                   rotation_angle=None, rot_axis=None, deg2rad=True,
                   center_CM=True):
         """Save structure data.
 
-        Parameters
-        ----------
-        fname : {None, str}, optional
-            file name string
-        structure_format : {None, str}, optional
-            chemical file format of saved structure data. Must be one of:
-
-                - xyz
-                - data
-
-            If `None`, then guess based on `fname` file extension or
-            default to `xyz` format.
-        rotation_angle : {None, float}, optional
-            Angle of rotation
-        rot_axis : {'x', 'y', 'z'}, optional
-            Rotation axis
-        deg2rad : bool, optional
-            Convert `rotation_angle` from degrees to radians.
-        center_CM : bool, optional
-            Center center-of-mass on origin.
+        See :meth:`~sknano.nanogen.StructureGenerator.save_data` method
+        for documentation.
 
         """
-        if (fname is None and structure_format not in
-                supported_structure_formats) or \
-                (fname is not None and not
-                    fname.endswith(supported_structure_formats) and
-                    structure_format not in supported_structure_formats):
-            structure_format = default_structure_format
-
         if fname is None:
             chirality = '{}{}f'.format('{}'.format(self._n).zfill(2),
                                        '{}'.format(self._m).zfill(2))
-
             nx = self.nx
             ny = self.ny
             fname_wordlist = None
@@ -503,20 +426,6 @@ class UnrolledNanotubeGenerator(Nanotube, StructureGenerator):
                 fname_wordlist = (chirality, nz)
 
             fname = '_'.join(fname_wordlist)
-            fname += '.' + structure_format
-        else:
-            if fname.endswith(supported_structure_formats) and \
-                    structure_format is None:
-                for ext in supported_structure_formats:
-                    if fname.endswith(ext):
-                        structure_format = ext
-                        break
-            else:
-                if structure_format is None or \
-                        structure_format not in supported_structure_formats:
-                    structure_format = default_structure_format
-
-        self._fname = fname
 
         if center_CM:
             self._structure_atoms.center_CM()
@@ -531,16 +440,10 @@ class UnrolledNanotubeGenerator(Nanotube, StructureGenerator):
             if center_CM:
                 self._structure_atoms.center_CM()
 
-        if rotation_angle is not None:
-            R_matrix = rotation_matrix(rotation_angle,
-                                       rot_axis=rot_axis,
-                                       deg2rad=deg2rad)
-            self._structure_atoms.rotate(R_matrix)
-
-        if structure_format == 'data':
-            DATAWriter.write(fname=self._fname, atoms=self._structure_atoms)
-        else:
-            XYZWriter.write(fname=self._fname, atoms=self._structure_atoms)
+        super(UnrolledNanotubeGenerator, self).save_data(
+            fname=fname, outpath=outpath, structure_format=structure_format,
+            rotation_angle=rotation_angle, rot_axis=rot_axis,
+            deg2rad=deg2rad, center_CM=False)
 
 
 class MWNTGenerator(NanotubeGenerator):
@@ -563,7 +466,7 @@ class MWNTGenerator(NanotubeGenerator):
         Number of repeat unit cells in the :math:`x, y, z` dimensions.
     element1, element2 : {str, int}, optional
         Element symbol or atomic number of basis
-        :py:class:`~sknano.chemistry.Atoms` 1 and 2
+        :class:`~sknano.chemistry.Atoms` 1 and 2
     bond : float, optional
         :math:`\\mathrm{a}_{\\mathrm{CC}} =` distance between
         nearest neighbor atoms. Must be in units of **Angstroms**.
@@ -602,8 +505,8 @@ class MWNTGenerator(NanotubeGenerator):
         value is the van der Waals interaction distance of 3.4 Angstroms.
     autogen : bool, optional
         if `True`, automatically call
-        :py:meth:`~MWNTGenerator.generate_unit_cell`,
-        followed by :py:meth:`~MWNTGenerator.generate_structure_data`.
+        :meth:`~MWNTGenerator.generate_unit_cell`,
+        followed by :meth:`~MWNTGenerator.generate_structure_data`.
     verbose : bool, optional
         if `True`, show verbose output
 
@@ -836,46 +739,20 @@ class MWNTGenerator(NanotubeGenerator):
             print('Nshells_per_tube: {}'.format(self._Nshells_per_tube))
             print('Natoms_per_tube: {}'.format(self._Natoms_per_tube))
 
-    def save_data(self, fname=None, structure_format=None,
+    def save_data(self, fname=None, outpath=None, structure_format=None,
                   rotation_angle=None, rot_axis=None, deg2rad=True,
                   center_CM=True):
         """Save structure data.
 
-        Parameters
-        ----------
-        fname : {None, str}, optional
-            file name string
-        structure_format : {None, str}, optional
-            chemical file format of saved structure data. Must be one of:
-
-                - `xyz`
-                - `data`
-
-            If `None`, then guess based on `fname` file extension or
-            default to `xyz` format.
-        rotation_angle : {None, float}, optional
-            Angle of rotation
-        rot_axis : {'x', 'y', 'z'}, optional
-            Rotation axis
-        deg2rad : bool, optional
-            Convert `rotation_angle` from degrees to radians.
-        center_CM : bool, optional
-            Center center-of-mass on origin.
+        See :meth:`~sknano.nanogen.StructureGenerator.save_data` method
+        for documentation.
 
         """
-        if (fname is None and structure_format not in
-                supported_structure_formats) or \
-                (fname is not None and not
-                    fname.endswith(supported_structure_formats) and
-                    structure_format not in supported_structure_formats):
-            structure_format = default_structure_format
-
         if fname is None:
             Nshells = '{}shell_mwnt'.format(self._Nshells_per_tube)
             chirality = '{}{}_{}_Ch'.format('{}'.format(self._n).zfill(2),
                                             '{}'.format(self._m).zfill(2),
                                             self._starting_shell_position)
-
             fname_wordlist = None
             if self._assume_integer_unit_cells:
                 nz = ''.join(('{}'.format(self._nz),
@@ -885,21 +762,8 @@ class MWNTGenerator(NanotubeGenerator):
                               plural_word_check('cell', self._nz)))
             fname_wordlist = (Nshells, chirality, nz)
             fname = '_'.join(fname_wordlist)
-            fname += '.' + structure_format
-
-        else:
-            if fname.endswith(supported_structure_formats) and \
-                    structure_format is None:
-                for ext in supported_structure_formats:
-                    if fname.endswith(ext):
-                        structure_format = ext
-                        break
-            else:
-                if structure_format is None or \
-                        structure_format not in supported_structure_formats:
-                    structure_format = default_structure_format
 
         super(MWNTGenerator, self).save_data(
-            fname=fname, structure_format=structure_format,
+            fname=fname, outpath=outpath, structure_format=structure_format,
             rotation_angle=rotation_angle, rot_axis=rot_axis,
             deg2rad=deg2rad, center_CM=center_CM)
