@@ -7,8 +7,8 @@ Parameter LUTs (:mod:`sknano.nanogen._parameter_luts`)
 .. currentmodule:: sknano.nanogen._parameter_luts
 
 """
-from __future__ import division, print_function, absolute_import
-__docformat__ = 'restructuredtext'
+from __future__ import absolute_import, division, print_function
+__docformat__ = 'restructuredtext en'
 
 param_units = {}
 param_units['dt'] = \
