@@ -7,17 +7,13 @@ Twisted nanotube bundles (:mod:`sknano.nanogen._twisted_bundle_generators`)
 .. currentmodule:: sknano.nanogen._twisted_bundle_generators
 
 """
-from __future__ import division, print_function, absolute_import
-__docformat__ = 'restructuredtext'
+from __future__ import absolute_import, division, print_function
+__docformat__ = 'restructuredtext en'
 
 #import copy
 #import itertools
 #import sys
 
-#from pint import UnitRegistry
-#ureg = UnitRegistry()
-#Qty = ureg.Quantity
-
 #import numpy as np
 
 from ..tools.refdata import CCbond
