@@ -13,10 +13,13 @@ Contents
    :toctree: generated/
 
    nanogen
+   nanogenui
 
 """
-from __future__ import print_function, absolute_import
+from __future__ import absolute_import, division, print_function
+__docformat__ = 'restructuredtext en'
 
 from .nanogen import *
+from .nanogenui import NanoGen
 
 __all__ = [s for s in dir() if not s.startswith('_')]
