@@ -7,16 +7,16 @@ LAMMPS data format (:mod:`sknano.structure_io._lammps_data_format`)
 .. currentmodule:: sknano.structure_io._lammps_data_format
 
 """
-from __future__ import division, print_function, absolute_import
-
-__docformat__ = 'restructuredtext'
+from __future__ import absolute_import, division, print_function
+__docformat__ = 'restructuredtext en'
 
 from collections import OrderedDict
 import os
 
 import numpy as np
 
-from ..chemistry import Atom, Atoms
+#from ..chemistry import Atom
+from .atoms import LAMMPSAtom as Atom
 from ..tools import get_fpath
 
 from ._structure_data import StructureReader, StructureWriter, \
@@ -93,17 +93,19 @@ atom_style_map['wavepacket'] = \
 
 
 class DATAReader(StructureReader):
-    """Class for reading `LAMMPS data` file format.
+    """`StructureReader` class for reading `LAMMPS data` file format.
 
     Parameters
     ----------
-    fname : str
-        LAMMPS data file
+    fpath : str
+        `LAMMPS data` file path
     atom_style : {'full', 'atomic'}, optional
 
     """
-    def __init__(self, fname=None, atom_style='full'):
-        super(DATAReader, self).__init__(fname=fname)
+    def __init__(self, fpath=None, atom_style='full'):
+        super(DATAReader, self).__init__(fpath=fpath)
+
+        #self._structure_atoms = LAMMPSAtoms()
 
         data_format = DATAFormat(atom_style=atom_style)
         self._data_headers = data_format.properties['headers']
@@ -115,17 +117,17 @@ class DATAReader(StructureReader):
         self._sections = {}
         self._boxbounds = {}
 
-        if fname is not None:
+        if fpath is not None:
             self.read()
 
     @property
     def headers(self):
-        """LAMMPS DATA file headers."""
+        """LAMMPS data file headers."""
         return self._headers
 
     @property
     def sections(self):
-        """LAMMPS DATA file sections."""
+        """LAMMPS data file sections."""
         return self._sections
 
     @property
@@ -135,7 +137,7 @@ class DATAReader(StructureReader):
 
     def read(self):
         """Read data file."""
-        with open(self._fname, 'r') as f:
+        with open(self.fpath, 'r') as f:
             self._comment_line = f.readline().strip()
 
             while True:
@@ -313,142 +315,147 @@ class DATAReader(StructureReader):
 
 
 class DATAWriter(StructureWriter):
-    """Class for writing LAMMPS data chemical file format."""
+    """`StructureWriter` class for writing `LAMMPS data` file format."""
 
     @classmethod
-    def write(cls, fname=None, atoms=None, boxbounds=None, comment_line=None,
-              assume_unique_atoms=False, enforce_consecutive_atomIDs=True,
-              pad_box=True, xpad=10., ypad=10., zpad=10., verbose=False):
+    def write(cls, fname=None, outpath=None, fpath=None, atoms=None,
+              boxbounds=None, comment_line=None, assume_unique_atoms=False,
+              enforce_consecutive_atomIDs=True, pad_box=True, xpad=10.,
+              ypad=10., zpad=10., verbose=False):
         """Write structure data to file.
 
         Parameters
         ----------
-        fname : str
-        atoms : :py:class:`~sknano.chemistry.Atoms`
-            An :py:class:`~sknano.chemistry.Atoms` instance.
+        fname : str, optional
+            Output file name.
+        outpath : str, optional
+            Output file path.
+        fpath : str, optional
+            Full path (directory path + file name) to output data file.
+        atoms : :class:`~sknano.chemistry.Atoms`
+            An :class:`~sknano.chemistry.Atoms` instance.
         boxbounds : dict, optional
             If `None`, determined automatically from the `atoms` coordinates.
         comment_line : str, optional
             A string written to the first line of `data` file. If `None`,
             then it is set to the full path of the output `data` file.
         assume_unique_atoms : bool, optional
-            Check that each :py:class:`~sknano.chemistry.Atom` in `atoms`
-            has a unique :py:attr:`~sknano.chemistry.Atom.atomID`.
+            Check that each :class:`~sknano.chemistry.Atom` in `atoms`
+            has a unique :attr:`~sknano.chemistry.Atom.atomID`.
             If the check fails, then assign a unique
-            :py:attr:`~sknano.chemistry.Atom.atomID` to each
-            :py:class:`~sknano.chemistry.Atom`.
+            :attr:`~sknano.chemistry.Atom.atomID` to each
+            :class:`~sknano.chemistry.Atom`.
             If `assume_unique_atoms` is True, but the atomID's are not unique,
             LAMMPS will not be able to read the data file.
         verbose : bool, optional
             verbose output
 
         """
-        if not isinstance(atoms, Atoms):
-            raise TypeError('atoms argument must be an `Atoms` instance')
-        else:
-            fname = get_fpath(fname=fname, ext='data', overwrite=True,
-                              add_fnum=False)
-            if comment_line is None:
-                #comment_line = fname
-                comment_line = default_comment_line
+        if fpath is None:
+            fpath = get_fpath(fname=fname, ext='data', outpath=outpath,
+                              overwrite=True, add_fnum=False)
+        if comment_line is None:
+            comment_line = default_comment_line
 
-            atoms.rezero_coords()
+        atoms.rezero_coords()
 
-            atomtypes = atoms.atomtypes
+        atomtypes = atoms.atomtypes
 
-            Natoms = atoms.Natoms
-            Natoms_width = \
-                8 if len(str(Natoms)) <= 12 else len(str(Natoms)) + 4
-            Ntypes = atoms.Ntypes
-            Ntypes_width = Natoms_width
+        Natoms = atoms.Natoms
+        Natoms_width = \
+            8 if len(str(Natoms)) <= 12 else len(str(Natoms)) + 4
+        Ntypes = atoms.Ntypes
+        Ntypes_width = Natoms_width
 
-            atomID_width = len(str(Natoms)) + 1
-            atomtype_width = len(str(Ntypes)) + 1
+        atomID_width = len(str(Natoms)) + 1
+        atomtype_width = len(str(Ntypes)) + 1
 
-            if (enforce_consecutive_atomIDs and
-                atoms.atom_ids.max() != atoms.Natoms) or \
-                    (not assume_unique_atoms and
-                     len(set(atoms.atom_ids)) != atoms.Natoms):
-                atoms.assign_unique_ids()
+        if (enforce_consecutive_atomIDs and
+            atoms.atom_ids.max() != atoms.Natoms) or \
+                (not assume_unique_atoms and
+                 len(set(atoms.atom_ids)) != atoms.Natoms):
+            atoms.assign_unique_ids()
 
-            if boxbounds is None:
-                boxbounds = {'x': {'min': None, 'max': None},
-                             'y': {'min': None, 'max': None},
-                             'z': {'min': None, 'max': None}}
+        if boxbounds is None:
+            boxbounds = {'x': {'min': None, 'max': None},
+                         'y': {'min': None, 'max': None},
+                         'z': {'min': None, 'max': None}}
 
-                for i, dim in enumerate(('x', 'y', 'z')):
-                    boxbounds[dim]['min'] = atoms.coords[:, i].min()
-                    boxbounds[dim]['max'] = atoms.coords[:, i].max()
+            for i, dim in enumerate(('x', 'y', 'z')):
+                boxbounds[dim]['min'] = atoms.coords[:, i].min()
+                boxbounds[dim]['max'] = atoms.coords[:, i].max()
 
-            boxpad = {'x': xpad, 'y': ypad, 'z': zpad}
-            pad_eps = 0.001
-            if pad_box:
-                #for dim, pad in boxpad.iteritems():
-                for i, dim in enumerate(('x', 'y', 'z')):
-                    pad = boxpad[dim]
-                    if abs(boxbounds[dim]['min'] - atoms.coords[:, i].min()) \
-                            < pad - pad_eps:
-                        boxbounds[dim]['min'] = boxbounds[dim]['min'] - pad
-                    if abs(boxbounds[dim]['max'] - atoms.coords[:, i].max()) \
-                            < pad - pad_eps:
-                        boxbounds[dim]['max'] = boxbounds[dim]['max'] + pad
+        boxpad = {'x': xpad, 'y': ypad, 'z': zpad}
+        pad_eps = 0.001
+        if pad_box:
+            #for dim, pad in boxpad.iteritems():
+            for i, dim in enumerate(('x', 'y', 'z')):
+                pad = boxpad[dim]
+                if abs(boxbounds[dim]['min'] - atoms.coords[:, i].min()) \
+                        < pad - pad_eps:
+                    boxbounds[dim]['min'] = boxbounds[dim]['min'] - pad
+                if abs(boxbounds[dim]['max'] - atoms.coords[:, i].max()) \
+                        < pad - pad_eps:
+                    boxbounds[dim]['max'] = boxbounds[dim]['max'] + pad
+
+        lohi_width = 0
+        for dim in ('x', 'y', 'z'):
+            lohi_width = \
+                max(lohi_width, len('{:.6f} {:.6f}'.format(
+                    boxbounds[dim]['min'], boxbounds[dim]['max'])) + 4)
+
+        with open(fpath, 'w') as f:
+            f.write('# {}\n\n'.format(comment_line.lstrip('#').strip()))
+            f.write('{}atoms\n'.format(
+                '{:d}'.format(Natoms).ljust(Natoms_width)))
+            f.write('{}atom types\n\n'.format(
+                '{:d}'.format(Ntypes).ljust(Ntypes_width)))
 
-            lohi_width = 0
             for dim in ('x', 'y', 'z'):
-                lohi_width = \
-                    max(lohi_width, len('{:.6f} {:.6f}'.format(
-                        boxbounds[dim]['min'], boxbounds[dim]['max'])) + 4)
+                f.write('{}{dim}lo {dim}hi\n'.format(
+                    '{:.6f} {:.6f}'.format(
+                        boxbounds[dim]['min'],
+                        boxbounds[dim]['max']).ljust(lohi_width),
+                    dim=dim))
 
-            with open(fname, 'w') as f:
-                f.write('# {}\n\n'.format(comment_line.lstrip('#').strip()))
-                f.write('{}atoms\n'.format(
-                    '{:d}'.format(Natoms).ljust(Natoms_width)))
-                f.write('{}atom types\n\n'.format(
-                    '{:d}'.format(Ntypes).ljust(Ntypes_width)))
+            f.write('\nMasses\n\n')
+            for atomtype, properties in atomtypes.iteritems():
+                f.write('{}{:.4f}\n'.format(
+                    '{:d}'.format(atomtype).ljust(Natoms_width),
+                    properties['mass']))
 
-                for dim in ('x', 'y', 'z'):
-                    f.write('{}{dim}lo {dim}hi\n'.format(
-                        '{:.6f} {:.6f}'.format(
-                            boxbounds[dim]['min'],
-                            boxbounds[dim]['max']).ljust(lohi_width),
-                        dim=dim))
+            f.write('\nAtoms\n\n')
+            for atom in atoms:
+                line = ''
+                line += "{:>{}}".format(atom.atomID, atomID_width)
+                line += "{:>{}}".format(atom.moleculeID, 3)
+                line += "{:>{}}".format(atom.atomtype, atomtype_width)
+                line += "{:>{}}".format('{:.1f}'.format(atom.q), 4)
+                line += "{:>{}}".format('{:f}'.format(atom.x), 14)
+                line += "{:>{}}".format('{:f}'.format(atom.y), 14)
+                line += "{:>{}}".format('{:f}'.format(atom.z), 14)
+                line += "{:>{}}".format('{:d}'.format(atom.nx), 3)
+                line += "{:>{}}".format('{:d}'.format(atom.ny), 3)
+                line += "{:>{}}".format('{:d}'.format(atom.nz), 3)
+                line += '\n'
 
-                f.write('\nMasses\n\n')
-                for atomtype, properties in atomtypes.iteritems():
-                    f.write('{}{:.4f}\n'.format(
-                        '{:d}'.format(atomtype).ljust(Natoms_width),
-                        properties['mass']))
+                f.write(line)
 
-                f.write('\nAtoms\n\n')
-                for atom in atoms:
-                    line = ''
-                    line += "{:>{}}".format(atom.atomID, atomID_width)
-                    line += "{:>{}}".format(atom.moleculeID, 3)
-                    line += "{:>{}}".format(atom.atomtype, atomtype_width)
-                    line += "{:>{}}".format('{:.1f}'.format(atom.q), 4)
-                    line += "{:>{}}".format('{:f}'.format(atom.x), 14)
-                    line += "{:>{}}".format('{:f}'.format(atom.y), 14)
-                    line += "{:>{}}".format('{:f}'.format(atom.z), 14)
-                    line += "{:>{}}".format('{:d}'.format(atom.nx), 3)
-                    line += "{:>{}}".format('{:d}'.format(atom.ny), 3)
-                    line += "{:>{}}\n".format('{:d}'.format(atom.nz), 3)
+            f.write('\nVelocities\n\n')
+            for atom in atoms:
+                line = ''
+                line += "{:>{}}".format(atom.atomID, atomID_width)
+                line += "{:>{}}".format('{:f}'.format(atom.vx), 14)
+                line += "{:>{}}".format('{:f}'.format(atom.vy), 14)
+                line += "{:>{}}".format('{:f}'.format(atom.vz), 14)
+                line += '\n'
 
-                    f.write(line)
-
-                f.write('\nVelocities\n\n')
-                for atom in atoms:
-                    line = ''
-                    line += "{:>{}}".format(atom.atomID, atomID_width)
-                    line += "{:>{}}".format('{:f}'.format(atom.vx), 14)
-                    line += "{:>{}}".format('{:f}'.format(atom.vy), 14)
-                    line += "{:>{}}\n".format('{:f}'.format(atom.vz), 14)
-
-                    f.write(line)
+                f.write(line)
 
 
 class DATA2XYZConverter(StructureConverter):
     """
-    Class for converting structure data from LAMMPS `data` to `xyz` format.
+    `StructureConverter` class for converting `LAMMPS data` to `xyz` format.
 
     .. versionadded:: 0.2.9
 
@@ -466,21 +473,21 @@ class DATA2XYZConverter(StructureConverter):
 
     @property
     def datafile(self):
-        """LAMMPS data file"""
+        """`LAMMPS data` file."""
         return self.infile
 
     @property
     def xyzfile(self):
-        """xyz file name."""
+        """`xyz` file name."""
         return self.outfile
 
     def convert(self, return_reader=False):
-        """Convert LAMMPS `data` to `xyz` chemical file format.
+        """Convert `LAMMPS data` to `xyz` chemical file format.
 
         Parameters
         ----------
         return_reader : bool, optional
-            return an instance of `XYZReader`
+            Return an instance of `XYZReader`
 
         Returns
         -------
@@ -489,27 +496,27 @@ class DATA2XYZConverter(StructureConverter):
         """
         from ._xyz_format import XYZReader, XYZWriter
 
-        datareader = DATAReader(fname=self._datafile)
+        datareader = DATAReader(fpath=self.infile)
         atoms = datareader.atoms
         comment_line = datareader.comment_line
 
-        XYZWriter.write(fname=self._xyzfile, atoms=atoms,
+        XYZWriter.write(fname=self.outfile, atoms=atoms,
                         comment_line=comment_line)
 
         if return_reader:
-            return XYZReader(fname=self._xyzfile)
+            return XYZReader(fpath=self.outfile)
 
 
 class DATAData(DATAReader):
-    """Class for reading and writing structure data in LAMMPS data format.
+    """Class for reading and writing `StructureData` in `LAMMPS data` format.
 
     Parameters
     ----------
-    fname : str, optional
+    fpath : str, optional
 
     """
-    def __init__(self, fname=None):
-        super(DATAData, self).__init__(fname=fname)
+    def __init__(self, fpath=None):
+        super(DATAData, self).__init__(fpath=fpath)
 
     def delete(self, key):
         pass
@@ -595,16 +602,18 @@ class DATAData(DATAReader):
         """
         try:
             if (datafile is None or datafile == '') and \
-                    (self.fname is None or self.fname == ''):
-                error_msg = '`datafile` must be a string at least 1 ' + \
-                    'character long.'
+                    (self.fpath is None or self.fpath == ''):
+                error_msg = \
+                    '`datafile` must be a string at least 1 character long.'
                 if datafile is None:
                     raise TypeError(error_msg)
                 else:
                     raise ValueError(error_msg)
             else:
-                datafile = self._fname
-            DATAWriter.write(fname=datafile, atoms=self._structure_atoms,
+                datafile = self.fpath
+
+            DATAWriter.write(fname=datafile,
+                             atoms=self._structure_atoms,
                              boxbounds=self._boxbounds,
                              comment_line=self._comment_line)
         except (TypeError, ValueError) as e:
@@ -618,7 +627,7 @@ LAMMPSDATA = DATAData
 
 
 class DATAError(StructureDataError):
-    """Exception raised for failed method calls.
+    """`StructureDataError` `Exception` for `LAMMPS data` file format.
 
     Parameters
     ----------
@@ -634,7 +643,7 @@ class DATAError(StructureDataError):
 
 
 class DATAFormat(StructureFormat):
-    """Class defining the structure file format for LAMMPS data.
+    """`StructureFormat` class defining properties for `LAMMPS data` format.
 
     Parameters
     ----------
