@@ -7,13 +7,12 @@ PDB format (:mod:`sknano.structure_io._pdb_format`)
 .. currentmodule:: sknano.structure_io._pdb_format
 
 """
-from __future__ import division, print_function, absolute_import
-
-__docformat__ = 'restructuredtext'
+from __future__ import absolute_import, division, print_function
+__docformat__ = 'restructuredtext en'
 
 from collections import OrderedDict
 
-from ..chemistry import Atom, Atoms
+#from .atoms import PDBAtom, PDBAtoms
 from ..tools import get_fpath
 
 from ._structure_data import StructureReader, StructureReaderError, \
@@ -27,19 +26,19 @@ class PDBReader(StructureReader):
 
     Parameters
     ----------
-    fname : str
+    fpath : str
         pdb structure file
 
     """
-    def __init__(self, fname=None):
-        super(PDBReader, self).__init__(fname=fname)
+    def __init__(self, fpath=None):
+        super(PDBReader, self).__init__(fpath=fpath)
 
-        if fname is not None:
+        if fpath is not None:
             self.read()
 
     def read(self):
         """Read PDB file."""
-        with open(self._fname, 'r') as f:
+        with open(self.fpath, 'r') as f:
             lines = f.readlines()
             for line in lines:
                 print(line)
@@ -49,33 +48,29 @@ class PDBWriter(StructureWriter):
     """Class for writing pdb chemical file format."""
 
     @classmethod
-    def write(cls, fname=None, atoms=None, comment_line=None):
+    def write(cls, fname=None, outpath=None, atoms=None, comment_line=None):
         """Write structure data to file.
 
         Parameters
         ----------
         fname : str
-        atoms : :py:class:`~sknano.chemistry.Atoms`
-            An :py:class:`~sknano.chemistry.Atoms` instance.
+        outpath : str, optional
+            Output path for structure data file.
+        atoms : :py:class:`~sknano.structure_io.atoms.Atoms`
+            An :py:class:`~sknano.structure_io.atoms.Atoms` instance.
         comment_line : str, optional
 
         """
-        if not isinstance(atoms, Atoms):
-            raise TypeError('atoms argument must be an `Atoms` instance')
-        else:
-            fname = get_fpath(fname=fname, ext='pdb', overwrite=True,
-                              add_fnum=False)
-            if comment_line is None:
-                comment_line = default_comment_line
+        fpath = get_fpath(fname=fname, ext='pdb', outpath=outpath,
+                          overwrite=True, add_fnum=False)
+        if comment_line is None:
+            comment_line = default_comment_line
 
-            atoms.rezero_coords()
+        atoms.rezero_coords()
 
-            with open(fname, 'w') as f:
-                f.write('{:d}\n'.format(atoms.Natoms))
-                f.write('{}\n'.format(comment_line))
-                for atom in atoms:
-                    f.write('{:>3s}{:15.8f}{:15.8f}{:15.8f}\n'.format(
-                        atom.symbol, atom.x, atom.y, atom.z))
+        with open(fpath, 'w') as f:
+            for atom in atoms:
+                f.write(PDBFormatter.format(atom))
 
 
 class PDBData(PDBReader):
@@ -83,12 +78,12 @@ class PDBData(PDBReader):
 
     Parameters
     ----------
-    fname : str, optional
+    fpath : str, optional
 
     """
-    def __init__(self, fname=None):
+    def __init__(self, fpath=None):
         try:
-            super(PDBData, self).__init__(fname=fname)
+            super(PDBData, self).__init__(fpath=fpath)
         except StructureReaderError:
             pass
 
@@ -107,9 +102,13 @@ class PDBFormat(StructureFormat):
         super(PDBFormat, self).__init__()
 
         self._records = OrderedDict()
-        #self._records['HEADER'] = header = {}
-        #self._records['TITLE'] = title = {}
-        #self._records['MASTER'] = {}
+
+        self._records['HEADER'] = header = {}
+        header['format'] = ''
+
+        self._records['TITLE'] = title = {}
+        title['format'] = ''
+
         self._records['ATOM'] = atom = {}
         atom['format'] = \
             '{:6}{:>5} {:>4}{:1}{:>3} {:1}{:>4}{:1}' + \
@@ -118,7 +117,11 @@ class PDBFormat(StructureFormat):
             '{:>6.2f}{:>6.2f}' + \
             '{:10}'.format('') + \
             '{:2}{:2}'
+
         self._records['CONECT'] = {}
+
+        self._records['MASTER'] = {}
+
         self._records['END'] = None
 
         self._properties['RECORDS'] = self._records
@@ -126,3 +129,11 @@ class PDBFormat(StructureFormat):
     @property
     def records(self):
         return self._records
+
+
+class PDBFormatter(object):
+    """Formatter class to convert a `PDBAtom` to a formatted string."""
+
+    @classmethod
+    def format(cls):
+        pass
