@@ -7,12 +7,12 @@ XYZ format (:mod:`sknano.structure_io._xyz_format`)
 .. currentmodule:: sknano.structure_io._xyz_format
 
 """
-from __future__ import division, print_function, absolute_import
-__docformat__ = 'restructuredtext'
+from __future__ import absolute_import, division, print_function
+__docformat__ = 'restructuredtext en'
 
 import os
 
-from ..chemistry import Atom, Atoms
+from ..chemistry import Atom
 from ..tools import get_fpath
 
 from ._structure_data import StructureReader, StructureReaderError, \
@@ -23,23 +23,23 @@ __all__ = ['XYZData', 'XYZReader', 'XYZWriter',
 
 
 class XYZReader(StructureReader):
-    """Class for reading xyz chemical file format.
+    """`StructureReader` class for reading `xyz` chemical file format.
 
     Parameters
     ----------
-    fname : str
-        xyz structure file
+    fpath : str
+        `xyz` structure file path.
 
     """
-    def __init__(self, fname=None):
-        super(XYZReader, self).__init__(fname=fname)
+    def __init__(self, fpath=None):
+        super(XYZReader, self).__init__(fpath=fpath)
 
-        if fname is not None:
+        if fpath is not None:
             self.read()
 
     def read(self):
-        """Read XYZ file."""
-        with open(self._fname, 'r') as f:
+        """Read `xyz` file."""
+        with open(self.fpath, 'r') as f:
             Natoms = int(f.readline().strip())
             self._comment_line = f.readline().strip()
             lines = f.readlines()
@@ -50,57 +50,61 @@ class XYZReader(StructureReader):
                         Atom(s[0], x=float(s[1]), y=float(s[2]), z=float(s[3]))
                     self._structure_atoms.append(atom)
             if self._structure_atoms.Natoms != Natoms:
-                error_msg = '`xyzfile` contained {} atoms '.format(
+                error_msg = '`xyz` data contained {} atoms '.format(
                     self._structure_atoms.Natoms) + 'but should contain ' + \
                     '{}'.format(Natoms)
                 raise StructureReaderError(error_msg)
 
 
 class XYZWriter(StructureWriter):
-    """Class for writing xyz chemical file format."""
+    """`StructureWriter` class for writing `xyz` chemical file format."""
 
     @classmethod
-    def write(cls, fname=None, atoms=None, comment_line=None):
+    def write(cls, fname=None, outpath=None, fpath=None, atoms=None,
+              comment_line=None):
         """Write structure data to file.
 
         Parameters
         ----------
-        fname : str
-        atoms : :py:class:`~sknano.chemistry.Atoms`
-            An :py:class:`~sknano.chemistry.Atoms` instance.
+        fname : str, optional
+            Output file name.
+        outpath : str, optional
+            Output file path.
+        fpath : str, optional
+            Full path (directory path + file name) to output data file.
+        atoms : :class:`~sknano.chemistry.Atoms`
+            An :class:`~sknano.chemistry.Atoms` instance.
         comment_line : str, optional
             A string written to the first line of `xyz` file. If `None`,
             then it is set to the full path of the output `xyz` file.
 
         """
-        if not isinstance(atoms, Atoms):
-            raise TypeError('atoms argument must be an `Atoms` instance')
-        else:
-            fname = get_fpath(fname=fname, ext='xyz', overwrite=True,
-                              add_fnum=False)
-            if comment_line is None:
-                comment_line = default_comment_line
+        if fpath is None:
+            fpath = get_fpath(fname=fname, ext='xyz', outpath=outpath,
+                              overwrite=True, add_fnum=False)
+        if comment_line is None:
+            comment_line = default_comment_line
 
-            atoms.rezero_coords()
+        atoms.rezero_coords()
 
-            with open(fname, 'w') as f:
-                f.write('{:d}\n'.format(atoms.Natoms))
-                f.write('{}\n'.format(comment_line))
-                for atom in atoms:
-                    f.write('{:>3s}{:15.8f}{:15.8f}{:15.8f}\n'.format(
-                        atom.symbol, atom.x, atom.y, atom.z))
+        with open(fpath, 'w') as f:
+            f.write('{:d}\n'.format(atoms.Natoms))
+            f.write('{}\n'.format(comment_line))
+            for atom in atoms:
+                f.write('{:>3s}{:15.8f}{:15.8f}{:15.8f}\n'.format(
+                    atom.symbol, atom.x, atom.y, atom.z))
 
 
 class XYZData(XYZReader):
-    """Class for reading and writing structure data in XYZ data format.
+    """Class for reading and writing `StructureData` in `xyz` format.
 
     Parameters
     ----------
-    fname : str, optional
+    fpath : str, optional
 
     """
-    def __init__(self, fname=None):
-        super(XYZData, self).__init__(fname=fname)
+    def __init__(self, fpath=None):
+        super(XYZData, self).__init__(fpath=fpath)
 
     def write(self, xyzfile=None):
         """Write xyz file.
@@ -112,7 +116,7 @@ class XYZData(XYZReader):
         """
         try:
             if (xyzfile is None or xyzfile == '') and \
-                    (self.fname is None or self.fname == ''):
+                    (self.fpath is None or self.fpath == ''):
                 error_msg = '`xyzfile` must be a string at least 1 ' + \
                     'character long.'
                 if xyzfile is None:
@@ -120,7 +124,7 @@ class XYZData(XYZReader):
                 else:
                     raise ValueError(error_msg)
             else:
-                xyzfile = self._fname
+                xyzfile = self.fpath
             XYZWriter.write(fname=xyzfile, atoms=self._structure_atoms,
                             comment_line=self._comment_line)
         except (TypeError, ValueError) as e:
@@ -129,7 +133,7 @@ class XYZData(XYZReader):
 
 class XYZ2DATAConverter(StructureConverter):
     """
-    Class for converting structure data from `xyz` to LAMMPS `data` format.
+    `StructureConverter` class for converting `xyz` to `LAMMPS data` format.
 
     Parameters
     ----------
@@ -170,15 +174,16 @@ class XYZ2DATAConverter(StructureConverter):
 
     @property
     def xyzfile(self):
+        """`xyz` file name."""
         return self.infile
 
     @property
     def datafile(self):
-        """LAMMPS data file name."""
+        """`LAMMPS data` file name."""
         return self.outfile
 
     def add_atom(self, atom=None):
-        """Add new atom to atoms.
+        """Add new `Atom` to `Atoms`.
 
         Parameters
         ----------
@@ -202,12 +207,12 @@ class XYZ2DATAConverter(StructureConverter):
             self._add_new_atomtypes = True
 
     def convert(self, return_reader=False):
-        """Convert xyz to LAMMPS data chemical file format.
+        """Convert `xyz` to `LAMMPS data` chemical file format.
 
         Parameters
         ----------
         return_reader : bool, optional
-            return an instance of :py:class:`~DATAReader`
+            return an instance of :class:`~DATAReader`
 
         Returns
         -------
@@ -216,7 +221,7 @@ class XYZ2DATAConverter(StructureConverter):
         """
         from ._lammps_data_format import DATAReader, DATAWriter
 
-        xyzreader = XYZReader(fname=self._xyzfile)
+        xyzreader = XYZReader(fpath=self.infile)
         atoms = xyzreader.atoms
         comment_line = xyzreader.comment_line
         if self._add_new_atoms:
@@ -225,25 +230,24 @@ class XYZ2DATAConverter(StructureConverter):
             atoms.add_atomtypes(self._new_atomtypes)
 
         if self._boxbounds is None:
-
             boxbounds = {'x': {'min': None, 'max': None},
                          'y': {'min': None, 'max': None},
                          'z': {'min': None, 'max': None}}
-
             for i, dim in enumerate(('x', 'y', 'z')):
                 boxbounds[dim]['min'] = atoms.coords[:, i].min()
                 boxbounds[dim]['max'] = atoms.coords[:, i].max()
         else:
             boxbounds = self._boxbounds
 
-        DATAWriter.write(fname=self._datafile, atoms=atoms,
+        DATAWriter.write(fname=self.outfile, atoms=atoms,
                          boxbounds=boxbounds, comment_line=comment_line,
                          pad_box=self._pad_box, xpad=self._xpad,
                          ypad=self._ypad, zpad=self._zpad)
 
         if return_reader:
-            return DATAReader(fname=self._datafile)
+            return DATAReader(fpath=self.outfile)
 
 
 class XYZFormat(StructureFormat):
+    """`StructureFormat` class defining properties for `xyz` format."""
     pass
