@@ -7,12 +7,14 @@ Base class for structure data atom (:mod:`sknano.structure_io.atoms._atom`)
 .. currentmodule:: sknano.structure_io.atoms._atom
 
 """
-from __future__ import division, absolute_import, print_function
-__docformat__ = 'restructuredtext'
+from __future__ import absolute_import, division, print_function
+__docformat__ = 'restructuredtext en'
+
+from collections import OrderedDict
 
 import numpy as np
 
-from ...tools import Point  # ,Vector
+from ...tools import Vector
 from ...tools.refdata import atomic_masses, atomic_mass_symbol_map, \
     atomic_numbers, atomic_number_symbol_map, element_symbols
 
@@ -38,7 +40,7 @@ class Atom(object):
         self._Z = None
         self._m = None
 
-        self._r = Point(x=x, y=y, z=z)
+        self._r = Vector(x=x, y=y, z=z)
 
         if isinstance(element, (int, float)):
             self._Z = int(element)
@@ -46,16 +48,14 @@ class Atom(object):
             try:
                 self._symbol = element_symbols[idx]
                 self._m = atomic_masses[self._symbol]
-            except KeyError as e:
-                print(e)
+            except KeyError:
                 print('unrecognized element number: {}'.format(element))
         elif isinstance(element, str):
             self._symbol = element
             try:
                 self._Z = atomic_numbers[self._symbol]
                 self._m = atomic_masses[self._symbol]
-            except KeyError as e:
-                print(e)
+            except KeyError:
                 print('Unrecognized atomic symbol: {}'.format(element))
         else:
             self._symbol = None
@@ -68,7 +68,7 @@ class Atom(object):
                         self._symbol = atomic_number_symbol_map[int(mass / 2)]
                     self._Z = atomic_numbers[self._symbol]
                     self._m = atomic_masses[self._symbol]
-                except KeyError as e:
+                except KeyError:
                     self._symbol = None
                     self._Z = None
                     self._m = mass
@@ -77,6 +77,14 @@ class Atom(object):
 
         self._attributes = ['symbol', 'Z', 'm', 'r']
 
+        self._atomdict = OrderedDict()
+        self._atomdict['symbol'] = self._symbol
+        self._atomdict['Z'] = self._Z
+        self._atomdict['m'] = self._m
+        self._atomdict['x'] = self._r.x
+        self._atomdict['y'] = self._r.y
+        self._atomdict['z'] = self._r.z
+
     def __str__(self):
         """Return string representation of atom."""
         atom_str = ''
@@ -85,6 +93,11 @@ class Atom(object):
                 'Atom {}: {}\n'.format(attr, getattr(self, '_' + attr))
         return atom_str
 
+    @property
+    def atomdict(self):
+        """Return dictionary of atom attributes."""
+        return self._atomdict
+
     @property
     def Z(self):
         """Atomic number :math:`Z`.
@@ -140,7 +153,7 @@ class Atom(object):
             :math:`x`-coordinate in units of **Angstroms**.
 
         """
-        self._r.x = value
+        self._r.x = self._atomdict['x'] = value
 
     @property
     def y(self):
@@ -164,7 +177,7 @@ class Atom(object):
             :math:`y`-coordinate in units of **Angstroms**.
 
         """
-        self._r.y = value
+        self._r.y = self._atomdict['y'] = value
 
     @property
     def z(self):
@@ -188,7 +201,7 @@ class Atom(object):
             :math:`z`-coordinate in units of **Angstroms**.
 
         """
-        self._r.z = value
+        self._r.z = self._atomdict['z'] = value
 
     @property
     def r(self):
@@ -200,11 +213,11 @@ class Atom(object):
             3-element ndarray of [:math:`x, y, z`] coordinates of `Atom`.
 
         """
-        return self._r.coords
+        return self._r.components
 
     @r.setter
     def r(self, value=np.ndarray):
-        """Set :math:`x, y, z` coordinates of atom.
+        """Set :math:`x, y, z` coordinates of `Atom`.
 
         Parameters
         ----------
@@ -213,7 +226,22 @@ class Atom(object):
             **Angstroms**.
 
         """
-        self._r.coords = value
+        self.x, self.y, self.z = value[0], value[1], value[2]
+
+    def fix_minus_zero_coords(self, epsilon=1.0e-10):
+        """Set really really small negative coordinates to zero.
+
+        Set all coordinates with absolute value less than
+        epsilon zero so we don't end up with -0.00000
+        coordinates in structure data output.
+
+        Parameters
+        ----------
+        epsilon : float
+            smallest allowed absolute value of any :math:`x,y,z` component.
+
+        """
+        self._r.fix_minus_zero_components(epsilon=epsilon)
 
     def rezero_coords(self, epsilon=1.0e-10):
         """Re-zero position coordinates near zero.
@@ -227,4 +255,4 @@ class Atom(object):
             smallest allowed absolute value of any :math:`x,y,z` component.
 
         """
-        self._r.rezero_coords()
+        self._r.rezero_components(epsilon=epsilon)
