@@ -7,7 +7,8 @@ Helper functions for string manipulation (:mod:`sknano.tools._strfuncs`)
 .. currentmodule:: sknano.tools._strfuncs
 
 """
-from __future__ import division, print_function, absolute_import
+from __future__ import absolute_import, division, print_function
+__docformat__ = 'restructuredtext en'
 
 __all__ = ['plural_word_check']
 
